summaryrefslogtreecommitdiffstats
path: root/src/reportdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/reportdialog.h')
-rw-r--r--src/reportdialog.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/reportdialog.h b/src/reportdialog.h
index 758c2d6..ea0579e 100644
--- a/src/reportdialog.h
+++ b/src/reportdialog.h
@@ -31,15 +31,16 @@ namespace Tellico {
*/
class ReportDialog : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor sets up the dialog.
*
* @param parent A pointer to the parent widget
* @param name The widget name
*/
- ReportDialog(QWidget* parent, const char* name=0);
+ ReportDialog(TQWidget* tqparent, const char* name=0);
virtual ~ReportDialog();
public slots:
@@ -57,7 +58,7 @@ private:
KHTMLPart* m_HTMLPart;
GUI::ComboBox* m_templateCombo;
Export::HTMLExporter* m_exporter;
- QString m_xsltFile;
+ TQString m_xsltFile;
};
} // end namespace
@@ -31,15 +31,16 @@ namespace Tellico {
* The constructor sets up the dialog.
*
- * @param parent A pointer to the parent widget
+ * @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/